@@ -47,6 +47,8 @@ from PyQt5.QtWidgets import QApplication
 from PyQt5.QtWidgets import QButtonGroup
 from PyQt5.QtWidgets import QCheckBox
 from PyQt5.QtWidgets import QComboBox
+from PyQt5.QtWidgets import QDialog
+from PyQt5.QtWidgets import QDialogButtonBox
 from PyQt5.QtWidgets import QFrame
 from PyQt5.QtWidgets import QGridLayout
 from PyQt5.QtWidgets import QGroupBox
@@ -307,6 +309,7 @@ class FunctionRunnableKernel(FunctionRunnable):
         while True:
             try:
                 io_msg = self.kernel.client.get_iopub_msg(timeout=1.0)
+
                 io_msg_type = io_msg['msg_type']
                 io_msg_content = io_msg['content']
 
@@ -359,17 +362,30 @@ class FunctionRunnableKernel(FunctionRunnable):
                             response = self.handle_input_request(prompt)
                             self.kernel.client.input(response)
 
-        msg = self.kernel.client.get_shell_msg(msg_id)
-        if msg['msg_type'] == "execute_reply":
-            status = msg['content']['status']
-            if status == 'error' and 'traceback' in msg['content']:
-                # self.signals.data.emit(f"{status = }")
-                traceback = msg['content']['traceback']
-                # self.signals.data.emit(remove_ansi_escape('\n'.join(traceback)))
-                self.signals.data.emit(Text.from_ansi('\n'.join(traceback)))
+        self.collect_response_payload(msg_id, timeout=1000)
 
         self.signals.finished.emit(self, self.func_name, True)
 
+    def collect_response_payload(self, msg_id, timeout: int):
+        shell_msg = self.kernel.client.get_shell_msg(msg_id, timeout=timeout)
+
+        msg_type = shell_msg["msg_type"]
+        msg_content = shell_msg["content"]
+
+        # rich.print("shell_msg = ", end='')
+        # rich.print(shell_msg)
+
+        if msg_type == "execute_reply":
+            status = msg_content['status']
+            if status == 'error' and 'traceback' in msg_content:
+                ...
+                # We are not sending this traceback anymore to the Console output
+                # as it was already handled in the context of the io_pub_msg.
+                # self.signals.data.emit(f"{status = }")
+                # traceback = msg_content['traceback']
+                # self.signals.data.emit(Text.from_ansi('\n'.join(traceback)))
+
+
 
 class FunctionRunnableQProcess(FunctionRunnable):
     def __init__(self, func: Callable, args: List, kwargs: Dict, input_queue: Queue):
@@ -979,6 +995,9 @@ class View(QMainWindow):
         self.cmd_log = cmd_log
         """The location of the command log files, provided as an argument."""
 
+        self.question_dialog: YesNoQuestion | None = None
+        """A half-modal dialog to answer questions from the runnable."""
+
         # Keep a record of the GUI Apps, because if their reference is garbage collected they will crash
 
         self._gui_apps = []
@@ -1256,15 +1275,64 @@ class View(QMainWindow):
 
     @pyqtSlot(str)
     def input_request(self, msg: str):
-        # The argument msg contains the last lines of the output on which the input request was recognized.
-        button = QMessageBox.question(
-            self,
-            "Input Request from Script",
-            "There was an input request from the running script. "
-            "The question is in the output console of the main GUI.\n\n"
-            "Please answer the question with Yes or No."
+        message = textwrap.dedent(
+            """\
+            Input Request from Script\n\n
+            There was an input request from the running script.
+            The question is in the output console of the main GUI.\n\n
+            Please answer the question with Yes or No.
+            """
         )
-        if button == QMessageBox.Yes:
-            self.input_queue.put("Y")
-        elif button == QMessageBox.No:
-            self.input_queue.put("N")
+
+        self.question_dialog = YesNoQuestion(message)
+
+        self._buttons_panel.setDisabled(True)
+        if self._args_panel is not None:
+            self._args_panel.setDisabled(True)
+
+        self.question_dialog.show()
+        self.question_dialog.button_box.accepted.connect(partial(self.answer, "Y"))
+        self.question_dialog.button_box.rejected.connect(partial(self.answer, "N"))
+
+        # The argument msg contains the last lines of the output on which
+        # the input request was recognized.
+
+        # button = QMessageBox.question(
+        #     self,
+        #     "Input Request from Script",
+        #     "There was an input request from the running script. "
+        #     "The question is in the output console of the main GUI.\n\n"
+        #     "Please answer the question with Yes or No."
+        # )
+        # if button == QMessageBox.Yes:
+        #     self.input_queue.put("Y")
+        # elif button == QMessageBox.No:
+        #     self.input_queue.put("N")
+
+    def answer(self, msg: str, *args, **kwargs):
+        self.input_queue.put(msg)
+        print(f"answer -> {msg=}, {args=}, {kwargs=}")
+        self.question_dialog.close()
+        self.question_dialog = None
+
+        self._buttons_panel.setDisabled(False)
+        if self._args_panel is not None:
+            self._args_panel.setDisabled(False)
+
+
+
+class YesNoQuestion(QDialog):
+    def __init__(self, message: str, parent=None):
+        super().__init__(parent)
+        self.setWindowTitle("Reply to Question")
+
+        buttons = QDialogButtonBox.Yes | QDialogButtonBox.No
+
+        self.button_box = QDialogButtonBox(buttons)
+
+        self.layout = QVBoxLayout()
+        message = QLabel(message)
+        self.layout.addWidget(message)
+        self.layout.addWidget(self.button_box)
+        self.setLayout(self.layout)
+        self.setWindowFlag(Qt.WindowStaysOnTopHint)
